#!/usr/bin/python
# -*- coding: UTF-8 -*-

"""
    Huawei DLI Python SDK
    The class DliInfo of DLI Python SDK
"""
from dli.exception import DliException


class DliInfo(object):
    def __init__(self, **kwargs):
        self._region = kwargs.get('region')
        self._project_id = kwargs.get('project_id')
        self._token = kwargs.get('token')
        self._auth_mode = kwargs.get('auth_mode')

        self._user = kwargs.get('user')
        self._account = kwargs.get('account')
        self._pwd = kwargs.get('password')

        self._ak = kwargs.get('ak')
        self._sk = kwargs.get('sk')

        self._domain = kwargs.get('domain')
        self._dli = kwargs.get('endpoint')
        self._iam = kwargs.get('iam_endpoint')
        self._obs = kwargs.get('obs.endpoint')

        self._check_param()

        if self._user is None:
            self._user = self._account

        if self._domain is None:
            self._domain = 'myhuaweicloud.com'

        if self._iam is None:
            self._iam = 'iam.' + self._region + '.' + self._domain

        if self._dli is None:
            self._dli = 'dli.' + self._region + '.' + self._domain

        if self._obs is None:
            self._obs = 'obs.' + self._region + '.' + self._domain

    def _check_param(self):
        if self._region is None or self._region == '':
            raise DliException(msg='The region is missing.')

        if self._project_id is None or self._project_id == '':
            raise DliException(msg='The project_id is missing.')

        if self._token is not None and self._auth_mode == 'aksk':
            raise DliException(msg='The confirm auth_mode is token or aksk.')

        if self._token is None and (self._auth_mode is None or self._auth_mode == ''):
            raise DliException(msg='The auth_mode is missing.')

        if self._auth_mode == 'aksk':
            if self._ak is None or self._ak == '':
                raise DliException(msg='The ak is missing.')

            if self._sk is None or self._sk == '':
                raise DliException(msg='The sk is missing.')

        if self._auth_mode == 'token':
            if self.token is None or self.token == '':
                if self._account is None or self._account == '':
                    raise DliException(msg='The account is missing.')

                if self._pwd is None or self._pwd == '':
                    raise DliException(msg='The password is missing.')

    @property
    def region(self):
        return self._region

    @property
    def ak(self):
        return self._ak

    @property
    def sk(self):
        return self._sk

    @property
    def iam(self):
        return self._iam

    @property
    def dli(self):
        return self._dli

    @property
    def obs(self):
        return self._obs

    @property
    def user(self):
        return self._user

    @property
    def project_id(self):
        return self._project_id

    @property
    def pwd(self):
        return self._pwd

    @property
    def account(self):
        return self._account

    @property
    def domain(self):
        return self._domain

    @property
    def token(self):
        return self._token
